@@ -1,6 +1,6 @@
 # Deb-o-Matic
 #
-# Copyright (C) 2007-2010 Luca Falavigna
+# Copyright (C) 2007-2012 Luca Falavigna
 #
 # Author: Luca Falavigna <dktrkranz@debian.org>
 #
@@ -17,14 +17,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 
-import gettext
-from ConfigParser import ConfigParser
+from gettext import install
 
-gettext.install("debomatic")
-
-Options = ConfigParser()
-acceptedqueue = list()
-packagequeue = dict()
-buildlock = None
-pbuilderlock = dict()
-running = True
+install("debomatic")
