@@ -1,7 +1,7 @@
 # Deb-o-Matic - Contents module
 #
 # Copyright (C) 2009 Alessio Treglia
-# Copyright (C) 2010 Luca Falavigna
+# Copyright (C) 2010-2012 Luca Falavigna
 #
 # Authors: Alessio Treglia <quadrispro@ubuntu.com>
 #          Luca Falavigna <dktrkranz@debian.org>
@@ -22,6 +22,8 @@
 # Store debc output in the pool directory.
 
 import os
+from subprocess import call
+
 
 class DebomaticModule_Contents:
 
@@ -37,5 +39,5 @@ class DebomaticModule_Contents:
                 changes_file = os.path.join(resultdir, filename)
                 break
         if changes_file:
-            os.system('%s %s > %s' % (self.debc, changes_file, contents_file))
-
+            with open(contents_file, 'w') as fd:
+                call([self.debc, changes_file], stdout=fd)
