@@ -1,7 +1,7 @@
 # Deb-o-Matic - Lintian module
 #
 # Copyright (C) 2008-2009 David Futcher
-# Copyright (C) 2008-2010 Luca Falavigna
+# Copyright (C) 2008-2012 Luca Falavigna
 #
 # Authors: David Futcher <bobbo@ubuntu.com>
 #          Luca Falavigna <dktrkranz@debian.org>
@@ -22,14 +22,20 @@
 # Stores litian output on top of the built package in the pool directory.
 
 import os
+from subprocess import call
+
 
 class DebomaticModule_Lintian:
 
     def __init__(self):
-        self.lintian = "/usr/bin/lintian"
+        self.lintian = '/usr/bin/lintian'
 
     def post_build(self, args):
         changesfile = None
+        if args['opts'].has_section('lintian'):
+            lintopts = args['opts'].get('lintian', 'lintopts').strip()
+        else:
+            lintopts = []
         resultdir = os.path.join(args['directory'], 'pool', args['package'])
         lintian = os.path.join(resultdir, args['package']) + '.lintian'
         for filename in os.listdir(resultdir):
@@ -37,6 +43,7 @@ class DebomaticModule_Lintian:
                 changesfile = os.path.join(resultdir, filename)
                 break
         if changesfile:
-            os.system('%s -V > %s' % (self.lintian, lintian))
-            os.system('%s --allow-root -i -I -E --pedantic %s >> %s' % (self.lintian, changesfile, lintian))
-
+            with open(lintian, 'w') as fd:
+                call([self.lintian, '-V'], stdout=fd)
+                cmd = [self.lintian] + lintopts.split() + [changesfile]
+                call(cmd, stdout=fd)
